@@ -157,7 +157,12 @@ if selective_loading:
 
         if name in ["help"]:
             Plugin.load()
-        if name in ['banner', 'stopwatch', 'clear', 'sleep', 'echo', 'pause']:
+        if name in ['banner',
+                    'stopwatch',
+                    'clear',
+                    'sleep',
+                    'echo',
+                    'pause']:
             name = Plugin.class_name("terminal")
             Plugin.load([name])
         else:
@@ -169,7 +174,6 @@ else:
     Plugin.load()
 StopWatch.stop("load")
 
-
 PluginCommandClasses = type(
     'CommandProxyClass',
     tuple(PluginCommand.__subclasses__()),
@@ -195,6 +199,35 @@ class CMShell(Cmd, PluginCommandClasses):
     +-------------------------------------------------------+
     """)
 
+
+    def set_debug(self, on):
+
+        def _boolean(value):
+            value = str(value).lower()
+            if value in ["true", "on"]:
+                value = True
+            elif value in ["false", "off"]:
+                value = False
+            else:
+                value = False
+                Console.error("Value is not boolean")
+            return value
+
+        variables = Variables()
+        if _boolean(on):
+            variables["debug"] = True
+            variables["trace"] = True
+            variables["verbose"] = '10'
+            variables["timer"] = True
+        else:
+            variables["debug"] = False
+            variables["trace"] = False
+            variables["verbose"] = '0'
+            variables["timer"] = False
+
+        for key in ["debug", "trace", "verbose", "timer"]:
+            print (f"{key}={variables[key]}")
+
     @command
     def do_commands(self, args, arguments):
         """
@@ -352,6 +385,34 @@ class CMShell(Cmd, PluginCommandClasses):
         #    return ""
 
         if cmd != '':
+
+            if cmd in ['dryrun']:
+                variables = Variables()
+                if arg.startswith("="):
+                    arg = arg[1:]
+                try:
+                    value = arg
+                    variables.boolean("dryrun", value)
+                except IndexError:
+                    Console.error("value for dryrun is missing")
+                except Exception as e:
+                    print(e)
+
+                return ""
+            elif cmd in ['debug']:
+                if arg.startswith("="):
+                    arg = arg[1:]
+                try:
+                    value = arg
+                    self.set_debug(value)
+                except IndexError:
+                    Console.error("value for dryrun is missing")
+                except Exception as e:
+                    print(e)
+
+                return ""
+
+
             try:
                 func = getattr(self, 'do_' + cmd)
                 return func(arg)
